"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OracleApi_1 = require("./OracleApi");
/**
 * Connects to the core services endpoints.
 */
class CoreApi extends OracleApi_1.OracleApi {
    /**
     * Returns a boot volume from the API.
     * @param {string} bootVolumeId The boot volume id.
     * @return {Promise}
     */
    getBootVolume(bootVolumeId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/bootVolumes/${bootVolumeId}`,
        });
    }
    /**
     * Connects to the get image endpoint.
     * @param {string} imageId The id of a specific image.
     * @return {Promise}
     */
    getImage(imageId) {
        const options = {
            host: this.servicesURI,
            method: 'GET',
            path: `/images/${imageId}`,
        };
        return this.call(options);
    }
    /**
     * Connects to the get instance endpoint.
     * @param {string} instanceId The ID of the specific instance.
     * @return {Promise}
     */
    getInstance(instanceId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/instances/${instanceId}`,
        });
    }
    /**
     * The get Volume endpoint.
     * @param {string} volumeId The id of the specific Volume.
     * @return {Promise}
     */
    getVolume(volumeId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/volumes/${volumeId}`,
        });
    }
    /**
     * Calls the listBootVolume endpoint.
     * @param {string} compartmentId The id of the compartment.
     * @return {Promsie}
     */
    listBootVolume(compartmentId) {
        const options = {
            host: this.servicesURI,
            method: 'GET',
            path: `/bootVolumes/?compartmentId=${compartmentId}`,
        };
        return this.call(options);
    }
    /**
     * Calls the listBootVolumeAttachments endpoint.
     * @param {string} availabilityDomain The availability domain.
     * @param {string} compartmentId The compartment id.
     * @param {string=} instanceId The id of the compute instance.
     * @param {number=} limit The number of items to return in a paginated call.
     * @param {page=} page The paginated page to retrieve.
     * @return {Promise}
     */
    listBootVolumeAttachments(availabilityDomain, compartmentId, instanceId, limit, page) {
        let qs = `?availabilityDomain=${encodeURIComponent(availabilityDomain)}` +
            `&compartmentId=${encodeURIComponent(compartmentId)}`;
        if (instanceId) {
            qs += `&instanceId=${instanceId}`;
        }
        if (limit) {
            qs += `&limit=${limit}`;
        }
        if (page) {
            qs += `&page=${page}`;
        }
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/bootVolumeAttachments/${qs}`,
        });
    }
    /**
     * Connects to the list endpoint.
     * @param {string} compartmentId The ID of the parent compartment.
     * @return {Promise}
     */
    listInstances(compartmentId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/instances/?compartmentId=${compartmentId}`,
        });
    }
    /**
     * Returns shapes from the API.
     * @param {string} compartmentId Of the specified compartment.
     * @return {Promise}
     */
    listShapes(compartmentId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/shapes/?compartmentId=${compartmentId}`,
        });
    }
    /**
     * List the volumes.
     * @param {stirng} compartmentId The id of the specific compartment.
     * @return {Promise}
     */
    listVolumes(compartmentId) {
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: '/volumes/?compartmentId=fakeid',
        });
    }
    /**
     * List volume attachment endpoint.
     * @param {string} compartmentId The compartment id.
     * @param {string} instanceId The instance id.
     * @return {Promise}
     */
    listVolumeAttachments(compartmentId, instanceId) {
        let qs = `?compartmentId=${compartmentId}`;
        if (instanceId) {
            qs += `&instanceId=${instanceId}`;
        }
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/volumeAttachments/${qs}`,
        });
    }
    /**
     * Returns a list of volume backups.
     * @param {string} compartmentId The compartment id of the backup.
     * @param {string=} volumeId The ID of a specific volume.
     * @return {Promise}
     */
    listVolumeBackups(compartmentId, volumeId) {
        let qs = `?compartmentId=${compartmentId}`;
        if (volumeId) {
            qs += `&volumeId=${volumeId}`;
        }
        return this.call({
            host: this.servicesURI,
            method: 'GET',
            path: `/volumeBackups${qs}`,
        });
    }
}
exports.CoreApi = CoreApi;
