"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const httpSignature = require("http-signature");
const https = require("https");
const jsSHA = require("jssha");
/**
 * The entry point to the Oracle Cloud API.
 */
class OracleApi {
    /**
     * Returns the identity URI.
     */
    get identityURI() {
        return `identity.${this.endpoint}.oraclecloud.com/20160918`;
    }
    /**
     * Returns the servies URI.
     */
    get servicesURI() {
        return `iaas.${this.endpoint}.oraclecloud.com/20160918`;
    }
    /**
     * Initiates the OracleCloudJs Object.
     * @param {Object} params The configuration object.
     */
    constructor(params) {
        this.endpoint = params.endpoint;
        this.fingerprint = params.fingerprint;
        this.privateKey = params.privateKey;
        this.userId = params.userId;
        this.tenancyId = params.tenancyId;
    }
    /**
     * Makes a call to the Oracle API.
     * @param {Object} opt The request options.
     * @param {Object} data The data to be sent to the API.
     * @return {Promsie} Promise of data received from the API.
     */
    call(opt, data) {
        return new Promise((resolve, reject) => {
            let req = https.request(opt, (res) => {
                let responseBody = '';
                res.on('data', (chunk) => responseBody += chunk);
                res.on('end', () => {
                    let returnValue = '';
                    try {
                        returnValue = JSON.parse(responseBody);
                    }
                    catch (e) {
                        // Fine. Don't be JSON.
                    }
                    resolve(returnValue || responseBody);
                });
            });
            req = this.sign(req, {
                body: data,
                keyFingerprint: this.fingerprint,
                privateKey: this.privateKey,
                tenancyId: this.tenancyId,
                userId: this.userId,
            });
            req.end();
        });
    }
    /**
     * Sign the request.
     * @param {Object} req The requset that is being sent to the API.
     * @param {Object} body Options to use with the request.
     * @return {Object}
     */
    sign(req, body) {
        const apiKeyId = `${this.tenancyId}/${this.userId}/${this.fingerprint}`;
        let headersToSign = ['host', 'date', '(request-target)'];
        if (/^PO?U?S?T$/.test(req.method)) {
            body = body || '';
            const shaObj = new jsSHA('SHA-256', 'TEXT');
            shaObj.update(body);
            req.setHeader('Content-Length', body.length);
            req.setHeader('x-content-sha256', shaObj.getHash('B64'));
            headersToSign = headersToSign.concat([
                'content-type',
                'content-length',
                'x-content-sha256',
            ]);
        }
        httpSignature.sign(req, {
            headers: headersToSign,
            key: this.privateKey,
            keyId: apiKeyId,
        });
        const newAuthHeaderValue = req.getHeader('Authorization')
            .replace('Signature ', 'Signature version="1",');
        req.setHeader('Authorization', newAuthHeaderValue);
        return req;
    }
}
exports.OracleApi = OracleApi;
